@@ -4,11 +4,13 @@ import logging
 import random
 import string
 import threading
+import time
 
 import rpyc
 from rpyc.utils.server import ThreadedServer
 
-from flexget.utils.tools import BufferQueue, console
+from flexget.utils.log import capture_output
+from flexget.utils.tools import console
 
 log = logging.getLogger('ipc')
 
@@ -16,11 +18,32 @@ log = logging.getLogger('ipc')
 rpyc.core.protocol.DEFAULT_CONFIG['safe_attrs'].update(['items'])
 rpyc.core.protocol.DEFAULT_CONFIG['allow_pickle'] = True
 
-IPC_VERSION = 1
+IPC_VERSION = 2
 AUTH_ERROR = 'authentication error'
 AUTH_SUCCESS = 'authentication success'
 
 
+class RemoteStream(object):
+    """
+    Used as a filelike to stream text to remote client. If client disconnects while this is in use, an error will be
+    logged, but no exception raised.
+    """
+    def __init__(self, writer):
+        """
+        :param writer: A function which writes a line of text to remote client.
+        """
+        self.writer = writer
+
+    def write(self, data):
+        if not self.writer:
+            return
+        try:
+            self.writer(data.rstrip('\n'))
+        except EOFError:
+            self.writer = None
+            log.error('Client ended connection while still streaming output.')
+
+
 class DaemonService(rpyc.Service):
     # This will be populated when the server is started
     manager = None
@@ -29,39 +52,43 @@ class DaemonService(rpyc.Service):
         return IPC_VERSION
 
     def exposed_execute(self, options=None):
-        # Dictionaries are pass by reference with rpyc, turn this into a real dict on our side
-        if options:
-            options = rpyc.utils.classic.obtain(options)
-        if len(self.manager.task_queue) > 0:
-            self.client_console('There is already a task executing. This task will execute next.')
-        log.info('Executing for client.')
-        cron = options and options.get('cron')
-        output = None if cron else BufferQueue()
-        tasks_finished = self.manager.execute(options=options, output=output)
+        with capture_output(self.client_out_stream):
+            if options:
+                # Dictionaries are pass by reference with rpyc, turn this into a real dict on our side
+                options = rpyc.utils.classic.obtain(options)
+            log.info('Adding execution for client.')
+            if len(self.manager.task_queue) > 0:
+                log.info('There is already an execution running. This one will execute next.')
+            cron = options and options.get('cron')
+            output = None if cron else self.client_out_stream
+            tasks_finished = self.manager.execute(options=options, output=output)
         if output:
-            # Send back any output until all tasks have finished
-            while any(not t.is_set() for t in tasks_finished) or output.qsize():
-                try:
-                    self.client_console(output.get(True, 0.5).rstrip())
-                except BufferQueue.Empty:
-                    continue
+            # The task logs are being streamed back to client, wait until they have finished
+            while any(not t.is_set() for t in tasks_finished):
+                time.sleep(0.3)
 
     def exposed_reload(self):
-        try:
-            self.manager.load_config()
-        except ValueError as e:
-            self.client_console('Error loading config: %s' % e.args[0])
-        else:
-            self.client_console('Config successfully reloaded from disk.')
+        with capture_output(self.client_out_stream):
+            log.info('Reloading config from disk.')
+            try:
+                self.manager.load_config()
+            except ValueError as e:
+                log.error('Error loading config: %s' % e.args[0])
+            else:
+                log.info('Config successfully reloaded from disk.')
 
     def exposed_shutdown(self, finish_queue=False):
-        log.info('Shutdown requested over ipc.')
-        self.client_console('Daemon shutdown requested.')
-        self.manager.shutdown(finish_queue=finish_queue)
+        with capture_output(self.client_out_stream):
+            log.info('Shutdown requested over ipc.')
+            self.manager.shutdown(finish_queue=finish_queue)
 
     def client_console(self, text):
         self._conn.root.console(text)
 
+    @property
+    def client_out_stream(self):
+        return RemoteStream(self._conn.root.console)
+
 
 class ClientService(rpyc.Service):
     def on_connect(self):
