@@ -1,8 +1,6 @@
 from __future__ import unicode_literals, division, absolute_import
 
-from nose.plugins.attrib import attr
-
-from tests import FlexGetBase
+from tests import FlexGetBase, use_vcr
 
 
 class TestInputSites(FlexGetBase):
@@ -22,22 +20,22 @@ class TestInputSites(FlexGetBase):
 
     """
 
-    @attr(online=True)
+    @use_vcr
     def test_rlslog(self):
         self.execute_task('test_rlslog')
         assert self.task.entries, 'no entries created / site may be down'
 
-    @attr(online=True)
+    @use_vcr
     def test_sceper(self):
         self.execute_task('test_sceper')
         assert self.task.entries, 'no entries created / site may be down'
 
-    @attr(online=True)
+    @use_vcr
     def test_apple_trailers(self):
         self.execute_task('test_apple_trailers')
         assert self.task.entries, 'no entries created / site may be down'
 
-    @attr(online=True)
+    @use_vcr
     def test_apple_trailers_simple(self):
         self.execute_task('test_apple_trailers_simple')
         assert self.task.entries, 'no entries created / site may be down'
